==> haskell-th-orphans-0.13.5-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.5
id: th-orphans-0.13.5-KbmBG7mw3GtGKLRO2h0mQq
key: th-orphans-0.13.5-KbmBG7mw3GtGKLRO2h0mQq
license: BSD3
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
author: Matt Morrow
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.TH.Instances
abi: 76fd17ac24a726ada686de18f1f83d75
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-orphans-0.13.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-orphans-0.13.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/th-orphans-0.13.5
hs-libraries: HSth-orphans-0.13.5-KbmBG7mw3GtGKLRO2h0mQq
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
    th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q
    th-reify-many-0.1.8-5GXK75rgh5BpNIIzzPuB7
    th-lift-instances-0.1.11-3bQxmESUBwW8ybCIwcRIFZ
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q=45860d93836c2d823f47ee3c78d7c61c
             th-reify-many-0.1.8-5GXK75rgh5BpNIIzzPuB7=d29018be4097cb22ac287f5463775599
             th-lift-instances-0.1.11-3bQxmESUBwW8ybCIwcRIFZ=475070fc63fc454093b7238ddec531ab
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.5-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.5
id: th-orphans-0.13.5-t0CEVQdE9c8I5D2IHhxnS
key: th-orphans-0.13.5-t0CEVQdE9c8I5D2IHhxnS
license: BSD3
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
author: Matt Morrow
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.TH.Instances
abi: 6ddf5551164c40b78e5ec80cc258bdd5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-orphans-0.13.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-orphans-0.13.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/th-orphans-0.13.5
hs-libraries: HSth-orphans-0.13.5-t0CEVQdE9c8I5D2IHhxnS
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
    th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q
    th-reify-many-0.1.8-5GXK75rgh5BpNIIzzPuB7
    th-lift-instances-0.1.11-3bQxmESUBwW8ybCIwcRIFZ
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q=45860d93836c2d823f47ee3c78d7c61c
             th-reify-many-0.1.8-5GXK75rgh5BpNIIzzPuB7=d29018be4097cb22ac287f5463775599
             th-lift-instances-0.1.11-3bQxmESUBwW8ybCIwcRIFZ=475070fc63fc454093b7238ddec531ab
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
